+++
title = "Attempt to replace non-existing keys"
tags = ["front-matter", "keys", "replace", "non-existing"]
draft = false
+++

Here, attempt is made to replace a non-existing key `toto`, but still,
there shouldn't be any error.
